Minnesota Supreme Court Opinions Index by Release Date

Minnesota Supreme Court Opinions & Orders
April - June 2014

#### June 25, 2014

- A12-1978, A12-2015, Lawrence Leiendecker, et al., Respondents, vs. Asian Women United of Minnesota, et al., Appellants (A12-1978), Greenstein, Mabley & Wall, L.L.C., et al., Respondents, Ruvelson & Kautzer, Ltd., et al., Respondents, Maria Gloria Fressia, et al., Appellants (A12-2015), Susan L. Triplett, Respondent.
- A13-1968, JME of Monticello, Inc., Relator, vs. Commissioner of Revenue, Respondent.
- List of ORDERS ON PETITIONS FOR FURTHER REVIEW FILED June 17, 2014.

#### June 18, 2014

- NO OPINIONS FILED
- A14-273, In re Petition for Disciplinary Action against Brian T. Hardwick, a Minnesota Attorney, Registration No. 41208. [AMENDED]
- A14-804, In re Petition for Disciplinary Action against Paul Roland Rambow, a Minnesota Attorney, Registration No. 169389
- ADM10-8041, ORDER PROMULGATING AMENDMENTS TO THE RULES OF JUVENILE PROTECTION PROCEDURE AND THE RULES OF ADOPTION PROCEDURE.

#### June 11, 2014

- A13-1959, Kim Thul Ouk, petitioner, Appellant, vs. State of Minnesota, Respondent.
- A13-491, In re Petition for Reinstatement of Alan J. Albrecht, a Minnesota Attorney, Registration No. 191826.
- ADM05-8001, In re Petition for Reinstatement to the Practice of Law of William Thomas Anderson, Registration No. 388198.

#### June 4, 2014

- NO OPINIONS FILED
- A14-273, In re Petition for Disciplinary Action against Brian T. Hardwick, a Minnesota Attorney, Registration No. 41208. [AMENDED]
- List of ORDERS ON PETITIONS FOR FURTHER REVIEW FILED May 28, 2014.

#### May 30, 2014

- A12-2270, Connie L. Gretsch, Appellant, vs. Vantium Capital, Inc., d/b/a Acqura Loan Services, Respondent. [ORDER]

#### May 28, 2014

- NO OPINIONS FILED
- List of ORDERS ON PETITIONS FOR FURTHER REVIEW FILED May 20, 2014.

#### May 21, 2014

- A12-1341, Jennifer Marie Axelberg, Appellant, vs. Commissioner of Public Safety, Respondent.
- A13-2169, Robert Michael Hughes, petitioner, Appellant, vs. State of Minnesota, Respondent.

#### May 14, 2014

- A13-4, State of Minnesota, Respondent, vs. Prince Oliver Moore, Jr., Appellant.
- A13-1548, In re Petition for Disciplinary Action against Willie Herman Davis, Jr., a Minnesota Attorney, Registration No. 298384.
- A13-1791, In re Petition for Disciplinary Action against Nicholas Bradley Schutz, a Minnesota Attorney, Registration No. 343675.
- A14-661, In re Petition for Disciplinary Action against Craig William Andresen, a Minnesota Attorney, Registration No. 186557.
- ADM10-8003, ORDER PROMULGATING AMENDMENTS TO THE MINNESOTA RULES OF JUVENILE DELINQUENCY PROCEDURE.

#### May 7, 2014

- A12-956, A13-922, State of Minnesota, Respondent, vs. Jerry Vang, Appellant.
- List of ORDERS ON PETITIONS FOR FURTHER REVIEW FILED April 29, 2014.

#### April 30, 2014

- A10-2145, In the Matter of: Vanessa Yolanda Rew, and o/b/o T.C.B. and D.S.B., Respondent, vs. James Allen Bergstrom, Appellant.
- A12-1856, A12-1867,State of Minnesota, by its Attorney General Lori Swanson, et al., Appellants (A12-1856), Covington & Burling, LLP, Appellant (A12-1867), City of Lake Elmo, Respondent, Metropolitan Council, Respondent, vs. 3M Company, Respondent.
- A13-519, In re Petition for Disciplinary Action against Randall D. B. Tigue, a Minnesota Attorney, Registration No. 110000.
- A14-20, In re Petition for Disciplinary Action against Paul Arthur Egtvedt, a Minnesota Attorney, Registration No. 282194.

#### April 23, 2014

- A12-1691, In the Matter of the Civil Commitment of: Cedrick Scott Ince.
- A13-1610, Interstate Traffic Signs, Inc., Relator, vs. Commissioner of Revenue, Respondent.
- List of ORDERS ON PETITIONS FOR FURTHER REVIEW FILED April 15, 2014.

#### April 16, 2014

- A13-483, Tony Allen Roman Nose, petitioner, Respondent, vs. State of Minnesota, Appellant.
- A13-184, In re Petition for Disciplinary Action against Amanda Lyn Koble, a Minnesota Attorney, Registration No. 386825.

#### April 9, 2014

- A12-1347, In the Matter of the Welfare of: B.A.H., Child.
- A12-1615, Harlan Poppler, et al., Respondents, vs. Wright Hennepin Cooperative Electric Association, Appellant.
- A12-1721, John Doe 169, Respondent, vs. Paul Alan Brandon, et al., Defendants, Minnesota District Council of the Assemblies of God, Appellant.
- A12-2272, Travis M. Minke, Respondent, vs. City of Minneapolis, et al., Appellants.
- A13-520, In re Petition for Disciplinary Action against Alan J. Albrecht, a Minnesota Attorney, Registration No. 191826.
- A12-1421, In re Petition for Disciplinary Action against Kenneth M. Bottema, a Minnesota Attorney, Registration No. 263795.

#### April 2, 2014

- A12-794, State of Minnesota, Appellant, vs. John Mark Hentges, Respondent.
- A12-1017, Minnesota Laborers Health and Welfare Fund, et al., Respondents, vs. Granite Re, Inc., Appellant, vs. Brent Anderson, Respondent, JoAnne M. Anderson, Respondent, EnviroTech Remediation Services, Inc., Respondent, Brent Krause, et al., Respondents, David P. Sobaski, Respondent, Karla P. Sobaski, Respondent.
- A12-2012, State of Minnesota, Appellant, vs. Guillermo Garcia-Gutierrez, Armando NMN Araiza, Aidan James Heine Mellgren, Terry Darnell Gilliam, Jr., and Jamie David Pintor-Velo, Respondents.
- A12-2270, Connie L. Gretsch, Appellant, vs. Vantium Capital, Inc., d/b/a Acqura Loan Services. [AMENDED]
- List of ORDERS ON PETITIONS FOR FURTHER REVIEW FILED March 26, 2014.

MSLL Home Page | | Minnesota Appellate Court System | | Archive Homepage

Phone: (651) 296-2775; Fax: (651) 296-6740

This site is continually being updated and we welcome your input.
Please send any comments or suggestions to the Webweaver.

Last update: June 25, 2014